@@ -3,7 +3,7 @@ use warnings;
 package Devel::REPL::Plugin::Commands;
 # ABSTRACT: Generic command creation plugin using injected functions
 
-our $VERSION = '1.003027';
+our $VERSION = '1.003028';
 
 use Devel::REPL::Plugin;
 use Scalar::Util qw(weaken);
@@ -81,13 +81,21 @@ Devel::REPL::Plugin::Commands - Generic command creation plugin using injected f
 
 =head1 VERSION
 
-version 1.003027
+version 1.003028
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
 
 =head1 AUTHOR
 
 Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>)
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
 
