@@ -1,10 +1,10 @@
 use strict;
 use warnings;
 package Devel::REPL::Plugin::CompletionDriver::INC;
-BEGIN {
-  $Devel::REPL::Plugin::CompletionDriver::INC::AUTHORITY = 'cpan:PHAYLON';
-}
-$Devel::REPL::Plugin::CompletionDriver::INC::VERSION = '1.003026';
+# ABSTRACT: Complete module names in use and require
+
+our $VERSION = '1.003028';
+
 use Devel::REPL::Plugin;
 use Devel::REPL::Plugin::Completion;    # die early if cannot load
 use File::Next;
@@ -129,16 +129,35 @@ around complete => sub {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::REPL::Plugin::CompletionDriver::INC - Complete module names in use and require
 
 =head1 VERSION
 
-version 1.003026
+version 1.003028
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
 
 =head1 AUTHOR
 
 Shawn M Moore, C<< <sartak at gmail dot com> >>
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
