@@ -3,7 +3,7 @@ use warnings;
 package Devel::REPL::Plugin::Interrupt;
 # ABSTRACT: Traps SIGINT to kill long-running lines
 
-our $VERSION = '1.003027';
+our $VERSION = '1.003028';
 
 use Devel::REPL::Plugin;
 use Sys::SigAction qw(set_sig_handler);
@@ -60,7 +60,7 @@ Devel::REPL::Plugin::Interrupt - Traps SIGINT to kill long-running lines
 
 =head1 VERSION
 
-version 1.003027
+version 1.003028
 
 =head1 DESCRIPTION
 
@@ -69,11 +69,19 @@ module, SIGINT will be trapped and used to kill long-running commands
 (statements) and also to kill the line being edited (like eg. BASH do). (You
 can still use Ctrl-D to exit.)
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
+
 =head1 AUTHOR
 
 Shawn M Moore, C<< <sartak at gmail dot com> >>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
 
