@@ -3,7 +3,7 @@ use warnings;
 package Devel::REPL::Plugin::Nopaste;
 # ABSTRACT: #nopaste to upload session's input and output
 
-our $VERSION = '1.003027';
+our $VERSION = '1.003028';
 
 use Devel::REPL::Plugin;
 use Moose::Util::TypeConstraints 'enum';
@@ -109,7 +109,7 @@ Devel::REPL::Plugin::Nopaste - #nopaste to upload session's input and output
 
 =head1 VERSION
 
-version 1.003027
+version 1.003028
 
 =head1 COMMANDS
 
@@ -156,11 +156,19 @@ the future parts of the session, not the past parts.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
+
 =head1 AUTHOR
 
 Shawn M Moore, C<< <sartak at gmail dot com> >>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
 
