@@ -1,10 +1,10 @@
 use strict;
 use warnings;
 package Devel::REPL::Plugin::PPI;
-BEGIN {
-  $Devel::REPL::Plugin::PPI::AUTHORITY = 'cpan:PHAYLON';
-}
-$Devel::REPL::Plugin::PPI::VERSION = '1.003026';
+# ABSTRACT: PPI dumping of Perl code
+
+our $VERSION = '1.003028';
+
 use Devel::REPL::Plugin;
 use PPI;
 use PPI::Dumper;
@@ -29,13 +29,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::REPL::Plugin::PPI - PPI dumping of Perl code
 
 =head1 VERSION
 
-version 1.003026
+version 1.003028
 
 =head1 SYNOPSIS
 
@@ -66,8 +68,23 @@ L<PPI>-parsed Perl documents.
 The code is not actually executed, which means that when used with
 L<Deve::REPL::Plugin::OutputCache> there is no new value in C<_>.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
+
 =head1 AUTHOR
 
 Shawn M Moore E<lt>sartak@gmail.comE<gt>
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
