@@ -1,19 +1,27 @@
 package Devel::REPL::Profile;
-BEGIN {
-  $Devel::REPL::Profile::AUTHORITY = 'cpan:PHAYLON';
-}
-$Devel::REPL::Profile::VERSION = '1.003026';
-use Moose::Role;
+# ABSTRACT: Code to execute when re.pl starts
 
+our $VERSION = '1.003028';
+
+use Moose::Role;
 requires 'apply_profile';
+use namespace::autoclean;
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Devel::REPL::Profile - code to execute when re.pl starts
+Devel::REPL::Profile - Code to execute when re.pl starts
 
 =head1 VERSION
 
-version 1.003026
+version 1.003028
 
 =head1 SYNOPSIS
 
@@ -82,14 +90,23 @@ assumed to be in the C<Devel::REPL::Profile::> namespace. Otherwise if you
 pass something which contains the C<::> character sequence, it will be loaded
 as-is.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
+
 =head1 AUTHOR
 
 Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>)
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This library is free software under the same terms as perl itself
+This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
